"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var index_exports = {};
__export(index_exports, {
  addClass: () => addClass,
  getOffsetTop: () => getOffsetTop,
  getOffsetTopDistance: () => getOffsetTopDistance,
  getStyle: () => getStyle,
  hasClass: () => hasClass,
  off: () => off,
  on: () => on,
  once: () => once,
  removeClass: () => removeClass,
  removeStyle: () => removeStyle,
  setStyle: () => setStyle,
  stop: () => stop
});
module.exports = __toCommonJS(index_exports);

// src/element.ts
var import_utils = require("@ly-js/utils");
function hasClass(el, cls) {
  if (!el || !cls) return false;
  if (cls.indexOf(" ") !== -1)
    throw new Error("className should not contain space.");
  if (el.classList) {
    return el.classList.contains(cls);
  } else {
    return (" " + el.className + " ").indexOf(" " + cls + " ") > -1;
  }
}
function addClass(el, cls) {
  if (!el) return;
  let curClass = el.className;
  const classes = (cls || "").split(" ");
  for (let i = 0, j = classes.length; i < j; i++) {
    const clsName = classes[i];
    if (!clsName) continue;
    if (el.classList) {
      el.classList.add(clsName);
    } else if (!hasClass(el, clsName)) {
      curClass += " " + clsName;
    }
  }
  if (!el.classList) {
    el.className = curClass;
  }
}
function removeClass(el, cls) {
  if (!el || !cls) return;
  const classes = cls.split(" ");
  let curClass = " " + el.className + " ";
  for (let i = 0, j = classes.length; i < j; i++) {
    const clsName = classes[i];
    if (!clsName) continue;
    if (el.classList) {
      el.classList.remove(clsName);
    } else if (hasClass(el, clsName)) {
      curClass = curClass.replace(" " + clsName + " ", " ");
    }
  }
  if (!el.classList) {
    el.className = (curClass || "").trim();
  }
}
var getStyle = function(element, styleName) {
  if (!import_utils.inBrowser) return;
  if (!element || !styleName) return null;
  styleName = (0, import_utils.camelize)(styleName);
  if (styleName === "float") {
    styleName = "cssFloat";
  }
  try {
    const style = element.style[styleName];
    if (style) return style;
    const computed = document.defaultView?.getComputedStyle(element, "");
    return computed ? computed[styleName] : "";
  } catch (e) {
    console.error(e?.toString());
    return element.style[styleName];
  }
};
function setStyle(element, styleName, value) {
  if (!element || !styleName) return;
  if ((0, import_utils.isObject)(styleName)) {
    Object.keys(styleName).forEach((prop) => {
      setStyle(element, prop, styleName[prop]);
    });
  } else {
    styleName = (0, import_utils.camelize)(styleName);
    element.style[styleName] = value;
  }
}
function removeStyle(element, style) {
  if (!element || !style) return;
  if ((0, import_utils.isObject)(style)) {
    Object.keys(style).forEach((prop) => {
      setStyle(element, prop, "");
    });
  } else {
    setStyle(element, style, "");
  }
}
var getOffsetTop = (el) => {
  let offset = 0;
  let parent = el;
  while (parent) {
    offset += parent.offsetTop;
    parent = parent.offsetParent;
  }
  return offset;
};
var getOffsetTopDistance = (el, containerEl) => {
  return Math.abs(getOffsetTop(el) - getOffsetTop(containerEl));
};

// src/event.ts
var on = function(element, event, handler, useCapture = false) {
  if (element && event && handler) {
    element.addEventListener(event, handler, useCapture);
  }
};
var off = function(element, event, handler, useCapture = false) {
  if (element && event && handler) {
    element.removeEventListener(event, handler, useCapture);
  }
};
var once = function(el, event, fn) {
  const listener = function(evt) {
    if (fn) {
      fn.apply(this, [evt]);
    }
    off(el, event, listener);
  };
  on(el, event, listener);
};
var stop = (e) => e.stopPropagation();
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  addClass,
  getOffsetTop,
  getOffsetTopDistance,
  getStyle,
  hasClass,
  off,
  on,
  once,
  removeClass,
  removeStyle,
  setStyle,
  stop
});
